;*
;* Raw Sample Playback Routines
;*
;*   Started 14-Jun-97
;*
;* Initials: JF = Jeff Frohwein
;*
;* V1.0 - 16-Jun-97 : Original Release - JF
;* V1.1 - 18-Aug-97 : Length included in data - JF
;* V1.2 - 29-Nov-97 : Interrupt handling taken out - JF
;*
;* Library Subroutines:
;*
;* snd_Sample1 -
;*    Playback raw sound sample at HL at 8192Hz rate.
;*
;*      The first DW at HL defines the length of the sample
;      in samples/32 or bytes/16. The format of the data at
;*     HL following the DW is 4-bit samples, 2 samples per
;*     byte, upper 4-bits played before lower 4 bits.
;*

; If all of these are already defined, don't do it again.

        IF      !DEF(SAMPLE1_ASM)
SAMPLE1_ASM  SET  1

rev_Check_sample1_asm: MACRO
;NOTE: REVISION NUMBER CHANGES MUST BE ADDED
;TO SECOND PARAMETER IN FOLLOWING LINE.
        IF      \1 > 1.2      ; <--- PUT REVISION NUMBER HERE
        WARN    "Version \1 or later of 'pan1.asm' is required."
        ENDC
        ENDM

; Definition includes

        INCLUDE "hardware.inc"          ;Hardware defines

; Make sure include files are useable revisions.

        rev_Check_hardware_inc   1.5

        SECTION "Sample1 Code",HOME

snd_Sample1::
        ld      a,[hl+]         ;get sample length
        ld      c,a
        ld      a,[hl+]
        ld      b,a

        ld      a,$84
        ldh      [rNR52],a      ;enable sound 3

        ld      a,0
        ldh     [rNR30],a
        ldh     [rNR51],a

        ld      a,$77
        ldh     [rNR50],a       ;select speakers
        ld      a,$ff
        ldh     [rNR51],a       ;enable sound 3

        ld      a,$80
        ldh     [rNR31],a       ;sound length
        ld      a,$20
        ldh     [rNR32],a       ;sound level high

        ld      a,$00
        ldh     [rNR33],a       ;sound freq low

.samp2:
        ld      de,_AUD3WAVERAM ;12
        push    bc              ;16
        ld      b,16            ;16

        xor     a
        ldh     [rNR30],a
.samp3:
        ld      a,[hl+]         ;8
        ld      [de],a          ;8
        inc     de              ;8
        dec     b               ;4
        jr      nz,.samp3       ;12

        ld      a,$80
        ldh     [rNR30],a

        ld      a,$87           ; (256hz)
        ldh     [rNR34],a


        ld      bc,558          ;delay routine
.samp4:
        dec     bc              ;8
        ld      a,b             ;4
        or      c               ;4
        jr      nz,.samp4       ;12

        ld      a,0             ;more delay
        ld      a,0
        ld      a,0

        pop     bc              ;12
        dec     bc              ;8
        ld      a,b             ;4
        or      c               ;4
        jr      nz,.samp2       ;12

        ld      a,$bb
        ldh     [rNR51],a       ;disable sound 3
        ret

        ENDC    ;sample1_asm

